-- 定制礼包
Lua_CustomGiftPanel = class("Lua_CustomGiftPanel", Lua_DisplayObject);
function Lua_CustomGiftPanel:ctor(p, skinName)
	self:superCall("ctor", p, skinName);
end

function Lua_CustomGiftPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardBg:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 1280 + self.adaptHeight);

	self.giftList = Lua_DragList.new(self.content, 660, 850 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.giftList:setListCell(Lua_CustomGiftItem, 660, 160, 1);
	self.giftList:setCellSpacing(0, 10);
	self.giftList:setLocation(0, -120, 0);

	self.introduceBtn:addClickFuntion(self, self.onTipsBtnClick);

	self:addLuaEvent("DRAW_CUSTOMGIFT_REWARD", self, self.customGiftEvent);
	self:addLuaEvent("UPDATE_CUSTOMGIFT_INFO", self, self.updateCustomGiftInfo);
end

function Lua_CustomGiftPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);

	self.rewardBg:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 1280 + adaptHeight);
	self.giftList:setContentRect(660, 850 + adaptHeight);
end

function Lua_CustomGiftPanel:setData(data)
	self.data = data;
	self:startTimer();
end

function Lua_CustomGiftPanel:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_CustomGiftPanel", 1, self, self.updateLeftTime);
	end
end

function Lua_CustomGiftPanel:updateLeftTime()
	if self.data.residueTime <= 0 then
		self:endTimer();
	end
	self.leftTimeTxt.text = LanUtil.formateStr("剩余时间：{1}", Lua_TimeTransform.transSeconds16(self.data.residueTime, true, true, true));
end

function Lua_CustomGiftPanel:endTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.updateLeftTime);
	end
end

function Lua_CustomGiftPanel:onTipsBtnClick(go)
	local tipData = { des = self.data.help_des, posX = 175, posY = -120 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_CustomGiftPanel:customGiftEvent(data)
	if DataCenter.backstageActData:checkActIsEnd(self.data) then
		return;
	end
	
	if data.eventType == 1 then
		Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sBuyCustomGift(self.data.actIdx, data.giftId);
	elseif data.eventType == 2 then
		Lua_WindowUtil.openWin("Lua_SelectCustomGiftWindow", Lua_WinParam.ACTION_OPEN, {actIdx = self.data.actIdx, giftInfo = data.giftInfo});
	end
end

function Lua_CustomGiftPanel:updateCustomGiftInfo()
	self.giftList:setArrayData(DataCenter.customGiftData.rewardArr);
end

function Lua_CustomGiftPanel:dispose()
	if self.giftList ~= nil then
		self.giftList:dispose();
		self.giftList = nil;
	end
	self.data = nil;
	self:endTimer();

	self:superCall("dispose");
end





--------------------------------------------------





Lua_CustomGiftItem = class("Lua_CustomGiftItem", Lua_ListCell);
function Lua_CustomGiftItem:ctor(p)
	self:superCall("ctor", p, "CustomGiftItem_skin");
end

function Lua_CustomGiftItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardList = Lua_DragList.new(self.content, 430, 125, Lua_AxisDefine.Horizontal);
	self.rewardList:setListCell(Lua_CustomGiftRewardItem, 112, 125, 1);
	self.rewardList:setLocation(-300, -13, 0);
	self.rewardList:setRectPivot(3);
	self:setSubList(self.rewardList);

	self.buyBtn:addClickFuntion(self, self.onBuyBtnClick);
end

function Lua_CustomGiftItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	local curCount = data.buy_limit - data.buy_times; -- 当前可购买数量
	self.tipsTxt.text = data.name;
	self.limitTimesTxt.text = LanUtil.formateStr("限购：<color=#45BC56>{1}</color>", curCount);

	if data.choose_num > #data.cur_rewards then
		self.buyBtn.label = "前往定制";
	else
		self.buyBtn.label = LanUtil.formateStr("{1}元", data.recharge_money);
	end

	self.rewardArr = Array();
	for i = 1, #data.all_reward do
		vo = {};
		vo.index = i; -- 分辨是固定还是可选奖励
		vo.id = data.id; -- 礼包ID
		vo.curCount = curCount; -- 当前可购买数量
		vo.fixed_num = data.fixed_num; -- 固定奖励个数
		vo.choose_num = data.choose_num; -- 可选择奖励个数
		vo.custom_rewards = data.custom_rewards; -- 可选奖励
		vo.cur_rewards = data.cur_rewards; -- 当前已定义礼包奖励
		vo.all_reward = data.all_reward; -- 整合后的全部奖励
		self.rewardArr:add(vo);
	end
	self.rewardList.canDrag = self.rewardArr:getSize() > 3;
	self.rewardList:setArrayData(self.rewardArr);

	self.buyBtn:setEnable(curCount > 0);
	self.sellOutSp:setEnable(curCount <= 0);
	self.limitTimesTxt:setEnable(curCount > 0);
	self:showRedDot(data.recharge_money <= 0 and curCount > 0);
end

function Lua_CustomGiftItem:showRedDot(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:setLocation(293, 36, 0);
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_CustomGiftItem:onBuyBtnClick()
	if self.data.choose_num > #self.data.cur_rewards then
		Lua_MsgUtil.callFunc("DRAW_CUSTOMGIFT_REWARD", {eventType = 2, giftInfo = self.rewardArr[self.data.fixed_num + 1]});
	else
		if self.data.recharge_money <= 0 then
			Lua_MsgUtil.callFunc("DRAW_CUSTOMGIFT_REWARD", {eventType = 1, giftId = self.data.id});
		else
			local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(self.data.recharge_id);
			DataCenter.sdkInterface:PointOut(1, tonumber(rechargeInfo.money), tonumber(rechargeInfo.money_type),
					tonumber(rechargeInfo.id), rechargeInfo.gift_name, rechargeInfo.gold);
		end
	end
end

function Lua_CustomGiftItem:dispose()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	if self.rewardArr ~= nil then
		self.rewardArr:dispose();
		self.rewardArr:clear();
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.data = nil;

	self:superCall("dispose");
end







--------------------------------------------------





Lua_CustomGiftRewardItem = class("Lua_CustomGiftRewardItem", Lua_ListCell);
function Lua_CustomGiftRewardItem:ctor(p)
	self:superCall("ctor", p, "CustomGiftRewardItem_skin");
end

function Lua_CustomGiftRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.giftIcon = Lua_ItemIcon.new(self.content);
	self.giftIcon:setSiblingIndex(2);
	self.giftIcon:setLocation(0, -5, 0);
	self.giftIcon:setScale(0.8, 0.8);
	self.giftIcon:setEnable(false);
end

function Lua_CustomGiftRewardItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.giftIcon:setEnable(true);
	if data.index <= data.fixed_num then
		self.giftIcon:setData(data.all_reward[data.index]);
		self.reSetIcon:setEnable(false);
	else
		if data.all_reward[data.index] == 0 then
			self.giftIcon:setData(nil);
			self.giftIcon:setEnable(false);
		else
			self.giftIcon:setData(data.all_reward[data.index]);
		end

		if data.curCount > 0 then
			self.reSetIcon:setEnable(data.all_reward[data.index] ~= nil);
		else
			self.reSetIcon:setEnable(false);
		end
	end
end

function Lua_CustomGiftRewardItem:onPressClick()
	if self.data == nil then
		return;
	end

	if self.data.index <= self.data.fixed_num then
		DataCenter.packUtil:showItemInfo(self.giftIcon.data);
	else
		if self.data.curCount > 0 then
			Lua_MsgUtil.callFunc("DRAW_CUSTOMGIFT_REWARD", {eventType = 2, giftInfo = self.data});
		else
			DataCenter.packUtil:showItemInfo(self.giftIcon.data);
		end
	end
end

function Lua_CustomGiftRewardItem:dispose()
	if self.giftIcon ~= nil then
		self.giftIcon:dispose();
		self.giftIcon = nil;
	end
	self.data = nil;

	self:superCall("dispose");
end