Lua_SelectCustomGiftWindow = class("Lua_SelectCustomGiftWindow", Lua_Window);
function Lua_SelectCustomGiftWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_SelectCustomGiftWindow";
	self.skinName = "SelectCustomGiftWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
	self.showClose = true;

	self.isFirst = true;
end

function Lua_SelectCustomGiftWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.btnClose:setLocation(300, 355, 0);

	self.selectGiftList = Lua_DragList.new(self.content, 520, 120, Lua_AxisDefine.Horizontal);
	self.selectGiftList.canDrag = false;
	self.selectGiftList:setListCell(Lua_SelectCustomGiftItem, 120, 120, 1);
	self.selectGiftList:setCellSpacing(0, 10);
	self.selectGiftList:setLocation(0, 220, 0);

	self.giftList = Lua_DragList.new(self.content, 575, 380, Lua_AxisDefine.Vertical);
	self.giftList:setListCell(Lua_SelectRewardItem, 112, 100, 5);
	self.giftList:setLocation(0, -50, 0);

	self.sureBtn:addClickFuntion(self, self.onSureBtnClick);

	self:addLuaEvent("UPDATE_SELF_SELECT", self, self.updateSelfSelect);
	self:addLuaEvent("UPDATE_SHOE_SELECT", self, self.updateShowSelect);
end

function Lua_SelectCustomGiftWindow:showWin(param)
	self:superCall("showWin", param);

	self:updateSelectedList(param.giftInfo);
	self:updateShowSelect(param.giftInfo.index - param.giftInfo.fixed_num);

	self.selectGiftList:setSelected(param.giftInfo.index - param.giftInfo.fixed_num);
end

function Lua_SelectCustomGiftWindow:onSureBtnClick(go)
	if self.selectedArr == nil then
		return;
	end

	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sDefineCustomGift(self.showData.actIdx, self.showData.giftInfo.id, self.selectedArr);
	self:hide();
end

function Lua_SelectCustomGiftWindow:updateSelectedList(param)
	if self.selectedArr == nil then
		self.selectedArr = Array();

		local selectedTab = self.showData.giftInfo.cur_rewards;
		local vo;
		for i = 1, param.choose_num do
			vo = { index = i, tvo = selectedTab[i] };
			self.selectedArr:add(vo);
		end

		self.selectGiftList:setArrayData(self.selectedArr);
		self.selectGiftList:setContentRect(120 * self.selectedArr:getSize(), 120);
	end
end

-- 更新自己选择的奖励
function Lua_SelectCustomGiftWindow:updateSelfSelect(data)
	if self.selectedArr == nil then
		return;
	end
	if self.giftIdx == nil then
		self.giftIdx = 1;
	end

	self.selectedArr[self.giftIdx].tvo = data;
	self.selectGiftList:setArrayData(self.selectedArr);
end

-- 更新显示的奖励
function Lua_SelectCustomGiftWindow:updateShowSelect(index)
	local tvo;
	if self.selectedArr ~= nil then
		tvo = self.selectedArr[index].tvo;
	end
	
	if self.giftIdx == index then
		DataCenter.packUtil:showItemInfo(tvo);
	end
	self.giftIdx = index;

	local selectedIdx = nil;
	local arr = Array();
	local customArr = self.showData.giftInfo.custom_rewards[index];
	local len = customArr:getSize();
	for i = 1, len do
		if tvo ~= nil and tvo.id == customArr[i].id and tvo.count == customArr[i].count then
			selectedIdx = i;
		end
		arr:add(customArr[i]);
	end
	self.giftList.curSelectedIdx = selectedIdx;
	self.giftList:setArrayData(arr);
end

function Lua_SelectCustomGiftWindow:dispose()
	if self.selectGiftList ~= nil then
		self.selectGiftList:dispose();
		self.selectGiftList = nil;
	end
	self.curRewardList = nil

	self:superCall("dispose");
end







--------------------------------------------------





Lua_SelectCustomGiftItem = class("Lua_SelectCustomGiftItem", Lua_ListCell);
function Lua_SelectCustomGiftItem:ctor(p)
	self:superCall("ctor", p, "SelectCustomGiftItem_skin");
end

function Lua_SelectCustomGiftItem:buildShowItem()
	self:superCall("buildShowItem");

	self.giftIcon = Lua_ItemIcon.new(self.content);
	self.giftIcon:setScale(0.8, 0.8);
	self.giftIcon:setEnable(false);
end

function Lua_SelectCustomGiftItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end
	
	if data.tvo ~= nil then
		self.giftIcon:setData(data.tvo);
		self.giftIcon:setEnable(true);
	else
		self.giftIcon:setData(nil);
		self.giftIcon:setEnable(false);
	end
end

function Lua_SelectCustomGiftItem:onPressClick()
	Lua_MsgUtil.callFunc("UPDATE_SHOE_SELECT", self.data.index);
	return true;
end

function Lua_SelectCustomGiftItem:onSelectionChange(selectState)
	self:superCall("onSelectionChange", selectState);

	self.selectIcon:setEnable(selectState);
end

function Lua_SelectCustomGiftItem:dispose()
	if self.giftIcon ~= nil then
		self.giftIcon:dispose();
		self.giftIcon = nil;
	end
	self.data = nil;

	self:superCall("dispose");
end







--------------------------------------------------





Lua_SelectRewardItem = class("Lua_SelectRewardItem", Lua_ListCell);
function Lua_SelectRewardItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_SelectRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setScale(0.8, 0.8);
end

function Lua_SelectRewardItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end
	self.itemIcon:setData(data);
end

function Lua_SelectRewardItem:onPressClick()
	if self.data == nil then
		return;
	end

	Lua_MsgUtil.callFunc("UPDATE_SELF_SELECT", self.data);
	return true;
end

function Lua_SelectRewardItem:onSelectionChange(selectState)
	self:superCall("onSelectionChange", selectState);
	self:updateShowSelect(selectState);
end

function Lua_SelectRewardItem:updateShowSelect(showState)
	if self.selectIcon == nil then
		self.selectIcon = UICreate.createUIAtlasImage(self.content, "common_altas_1", "ui_common_window_014", 0, 0, 0, 0);
	end
	self.selectIcon:setEnable(showState);
end

function Lua_SelectRewardItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	if self.selectIcon ~= nil then
		self.selectIcon:dispose();
		self.selectIcon = nil;
	end
	self.data = nil;

	self:superCall("dispose");
end