-- 幸运礼盒
Lua_LuckyGiftBoxPanel = class("Lua_LuckyGiftBoxPanel", Lua_DisplayObject);
function Lua_LuckyGiftBoxPanel:ctor(p, skinName)
	self:superCall("ctor", p, skinName);
end

function Lua_LuckyGiftBoxPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardBg:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 875 + self.adaptHeight);

	self.curRewardIcon = Lua_ItemIcon.new(self.content);
	self.curRewardIcon:setLocation(0, -247, 0);
	self.curRewardIcon:setRectAnchor(1);
	self.curRewardIcon:setSiblingIndex(11);
	self.curRewardIcon:setScale(145 / 112, 145 / 112);

	self.giftList = Lua_DragList.new(self.content, 610, 610 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.giftList:setListCell(Lua_LuckyGiftBoxItem, 122, 122, 5);
	self.giftList:setLocation(0, -80, 0);

	self.detailInfoBtn:addClickFuntion(self, self.onDetailInfoClick);
	self.luckyRewardicon:addClickFuntion(self, self.onSelectGiftClick);
	self.actCoinIcon:addClickFuntion(self, self.onItemInfoClick);
	self.addIcon:addClickFuntion(self, self.onItemInfoClick);
	self.nextEnterBtn:addClickFuntion(self, self.onNextEnterClick);

	self:addLuaEvent("DRAW_LUCKYGIFTBOX_REWARD", self, self.drawLuckyGiftBoxReward);
	self:addLuaEvent("UPDATE_LUCKYGIFTBOX_INFO", self, self.updateLuckyGiftBoxInfo);
end

function Lua_LuckyGiftBoxPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);

	self.rewardBg:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 875 + adaptHeight);
	
	local height = DataCenter.luckyGiftBoxData.box_max_count / 5 * 122;
	self.giftList:setContentRect(610, height + adaptHeight);
end

function Lua_LuckyGiftBoxPanel:setData(data)
	self.data = data;
	self:startTimer();
end

function Lua_LuckyGiftBoxPanel:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_LuckyGiftBoxPanel", 1, self, self.updateLeftTime);
	end
end

function Lua_LuckyGiftBoxPanel:updateLeftTime()
	if self.data.residueTime <= 0 then
		self:endTimer();
	end
	self.leftTimeTxt.text = LanUtil.formateStr("剩余时间：{1}", Lua_TimeTransform.transSeconds16(self.data.residueTime, true, true, true));
end

function Lua_LuckyGiftBoxPanel:endTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.updateLeftTime);
	end
end

function Lua_LuckyGiftBoxPanel:onDetailInfoClick(go)
	if DataCenter.backstageActData:checkActIsEnd(self.data) then
		return;
	end
	Lua_WindowUtil.openWin("Lua_LuckyGiftBoxDetailWindow", Lua_WinParam.ACTION_OPEN, self.data.actIdx);
end

function Lua_LuckyGiftBoxPanel:onSelectGiftClick(go)
	if DataCenter.backstageActData:checkActIsEnd(self.data) then
		return;
	end

	local isDraw = DataCenter.luckyGiftBoxData.isDraw;
	if isDraw then
		OperateAlert.show("本轮终极奖励已领取");
	else
		Lua_WindowUtil.openWin("Lua_SelectBestGiftBoxWindow", Lua_WinParam.ACTION_OPEN, self.data.actIdx);
	end
end

function Lua_LuckyGiftBoxPanel:onItemInfoClick(go)
	local tvo = Lua_ToolVo.createToolVo(DataCenter.luckyGiftBoxData.activity_item_id);
	DataCenter.packUtil:openPathWindow(tvo, false);
end

function Lua_LuckyGiftBoxPanel:onNextEnterClick(go)
	if DataCenter.backstageActData:checkActIsEnd(self.data) then
		return;
	end

	if DataCenter.luckyGiftBoxData.isDraw then
		local tipsData = {
			des = "<color=#846651>是否确认可进入下一轮抽奖</color>",
			posX = 0,
			posY = 85,
			btnType = 1,
			owner = self,
			sureFun = self.sEnterNext
		};
		Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
	end
end

function Lua_LuckyGiftBoxPanel:sEnterNext()
	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sStartNextRounds(self.data.actIdx);
end

function Lua_LuckyGiftBoxPanel:drawLuckyGiftBoxReward(giftIdx)
	if DataCenter.backstageActData:checkActIsEnd(self.data) then
		return;
	end

	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sDrawLuckyGiftBox(self.data.actIdx, giftIdx);
end

function Lua_LuckyGiftBoxPanel:updateLuckyGiftBoxInfo()
	local luckyGiftBoxData = DataCenter.luckyGiftBoxData;
	self.banner:setAltas(luckyGiftBoxData.icon_config[1].icon_atlas, luckyGiftBoxData.icon_config[1].icon_index);
	self.limitTimesTxt.text = LanUtil.formateStr("寻宝次数：<color=#45BC56>{1}/{2}</color>", luckyGiftBoxData.cost_residue_times, luckyGiftBoxData.cost_max_times);

	local tvo = Lua_ToolVo.createToolVo(luckyGiftBoxData.activity_item_id);
	self.actCoinIcon:setAltas(tvo.atlas, tvo.sprite);
	self.actCoinTxt.text = numberTrans(DataCenter.packData:getItemCountById(luckyGiftBoxData.activity_item_id));

	tvo = Lua_ToolVo.createToolVo(luckyGiftBoxData.advance_gift_id, luckyGiftBoxData.advance_gift_amount);
	self.curRewardIcon:setData(tvo);

	tvo = Lua_ToolVo.createToolVo(luckyGiftBoxData.cost_item_id);
	self.curLuckyDrawTxt.text = LanUtil.formateStr("消耗<color=#45BC56>{1}{2}</color>进行一次抽奖", tvo.name, luckyGiftBoxData.cost_item_amount);

	local maxCount = luckyGiftBoxData.box_max_count;
	local arr = Array();
	for i = 1, maxCount do
		arr:add(i);
	end
	self.giftList:setArrayData(arr);
	self.giftList:setContentRect(610, arr:getSize() / 5 * 122 + self.adaptHeight);
	self.giftList.canDrag = arr:getSize() > 25 or self.adaptHeight < 0;

	self.mask:setEnable(luckyGiftBoxData.isDraw);
	self.receivedIcon:setEnable(luckyGiftBoxData.isDraw);
	self.reSelectIcon:setEnable(not luckyGiftBoxData.isDraw);
	self.nextEnterBtn:setStyle(luckyGiftBoxData.isDraw and 1 or 3);

	local showState = luckyGiftBoxData.is_last_round == 1; -- maxCount == luckyGiftBoxData.drawCount and 
	self.nextEnterBtn:setEnable(not showState);

	-- 全部奖励抽完之后请求界面信息
	if maxCount == luckyGiftBoxData.drawCount and luckyGiftBoxData.is_last_round == 0 then
		if DataCenter.backstageActData:checkActIsEnd(self.data) then
			return;
		end
		self:startCheckTimer();
	end
end

function Lua_LuckyGiftBoxPanel:startCheckTimer()
	if self.onCheckCountDown ~= true then
		self.onCheckCountDown = true;
		Lua_CommonUtil.delayCall(1.5, self, self.updateCheckLeftTime);
	end
end

function Lua_LuckyGiftBoxPanel:updateCheckLeftTime()
	self:endCheckTimer();
end

function Lua_LuckyGiftBoxPanel:endCheckTimer()
	if self.onCheckCountDown == true then
		self.onCheckCountDown = false;
		Lua_CommonUtil.removeTimer(self, self.updateCheckLeftTime);

		tipsData = {};
		tipsData.owner = self;
		tipsData.callBack = self.updataInterface;
		Lua_WindowUtil.openWin("Lua_LuckyGiftBoxTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
	end
end

function Lua_LuckyGiftBoxPanel:updataInterface()
	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sActivityInfo(self.data.actIdx);
end

function Lua_LuckyGiftBoxPanel:dispose()
	if self.luckyRewardicon ~= nil then
		self.luckyRewardicon:dispose();
		self.luckyRewardicon = nil;
	end
	if self.giftList ~= nil then
		self.giftList:dispose();
		self.giftList = nil;
	end
	self.data = nil;
	self:endTimer();
	self:endCheckTimer();

	self:superCall("dispose");
end





--------------------------------------------------





Lua_LuckyGiftBoxItem = class("Lua_LuckyGiftBoxItem", Lua_ListCell);
function Lua_LuckyGiftBoxItem:ctor(p)
	self:superCall("ctor", p, "LuckyGiftBoxItem_skin");
end

function Lua_LuckyGiftBoxItem:buildShowItem()
	self:superCall("buildShowItem");

	self.giftIcon = Lua_ItemIcon.new(self.content);
	self.giftIcon:setSiblingIndex(1);
	self.giftIcon:setEnable(false);
end

function Lua_LuckyGiftBoxItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end
	self.time = getTime();

	self.boxIcon:setEnable(true);
	self.boxIcon:setScale(1, 1, 1);
	self.giftIcon:setEnable(true);

	local luckyGiftBoxData = DataCenter.luckyGiftBoxData;
	local giftInfo = luckyGiftBoxData.luckyBoxInfoDic[data];
	if giftInfo ~= nil then
		if giftInfo.cell_index == luckyGiftBoxData.curGiftIdx and luckyGiftBoxData.showState then
			self.giftIcon:setData(giftInfo.tvo);
			self.giftIcon:setScale(0, 1, 1);

			TweenUtil.getInstance():addTween(self.boxIcon.mainContent, 0.35, 0, 
			0, 0, 0, 
			0, 0, 0, 
			0, 1, 1, 
			self, self.onBoxComplete, 0, false);
		else
			self.boxIcon:setEnable(false);
			self.giftIcon:setData(giftInfo.tvo);
		end
	else
		self.giftIcon:setData(nil);
		self.giftIcon:setEnable(false);
	end
end

function Lua_LuckyGiftBoxItem:onBoxComplete()
	TweenUtil.getInstance():stop(self.boxIcon.mainContent);
	self.boxIcon:setEnable(false);

	TweenUtil.getInstance():addTween(self.giftIcon.mainContent, 0.35, 0, 
	0, 0, 0, 
	0, 0, 0, 
	1, 1, 1, 
	self, self.onRewardComplete, 0, false);
end

function Lua_LuckyGiftBoxItem:onRewardComplete()
	TweenUtil.getInstance():stop(self.giftIcon.mainContent);

	local luckyGiftBoxData = DataCenter.luckyGiftBoxData;
	local giftInfo = luckyGiftBoxData.luckyBoxInfoDic[self.data];
	if giftInfo ~= nil then
		if luckyGiftBoxData.showState then
			if giftInfo.tvo.id == luckyGiftBoxData.advance_gift_id and giftInfo.tvo.count == luckyGiftBoxData.advance_gift_amount then
				local arr = Array();
				arr:add(giftInfo.tvo);
				Lua_WindowUtil.openWin("Lua_ObtainItemTipsWindow", Lua_WinParam.ACTION_OPEN, arr);
			else
				OperateAlert.show(LanUtil.formateStr("获得{1}奖励 x{2}", giftInfo.tvo.name, giftInfo.tvo.count));
			end
		end
		luckyGiftBoxData.showState = false;
	end
end

function Lua_LuckyGiftBoxItem:onPressClick()
	if getTime() - self.time < 1 and DataCenter.luckyGiftBoxData.showState then
		OperateAlert.show("点击太快");
		return;
	end
	self.time = getTime();

	local luckyGiftBoxData = DataCenter.luckyGiftBoxData;
	local giftInfo = luckyGiftBoxData.luckyBoxInfoDic[self.data];
	if giftInfo ~= nil then
		DataCenter.packUtil:showItemInfo(giftInfo.tvo);
	else
		if luckyGiftBoxData.cost_type == 3 then -- 3 消耗活动道具
			self:sDrawBox();
		elseif luckyGiftBoxData.cost_type == 2 or luckyGiftBoxData.cost_type == 1 then -- 2 折扣钻石，1 原价钻石
			local costCount = luckyGiftBoxData.cost_item_amount;
			local curCount = DataCenter.moneyData:getMoney(Lua_ResourcesDefine.DIAMOND);
			if curCount > costCount then
				if not DataCenter.neverTipData:getNeverValue(Lua_NeverTipDefine.LUCKYGIFTBOX) then
					local str = spliceIconStrById(Lua_ResourcesDefine.DIAMOND);
					local tipsData = {
						des = LanUtil.formateStr("<color=#846651>是否使用{1}{2}(拥有:{3})兑换1个抽奖券并进行1次抽奖?</color>", str, costCount, curCount),
						posY = 110,
						btnType = 1,
						neverTip = Lua_NeverTipDefine.LUCKYGIFTBOX,
						owner = self,
						sureFun = self.sDrawBox
					};
					Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
				else
					self:sDrawBox();
				end
			else
				local tvo = Lua_ToolVo.createToolVo(luckyGiftBoxData.activity_item_id);
				DataCenter.packUtil:openPathWindow(tvo, false);
			end
		else -- 0 钻石和道具次数都不足
			local tvo = Lua_ToolVo.createToolVo(luckyGiftBoxData.activity_item_id);
			DataCenter.packUtil:openPathWindow(tvo, false);
		end
	end
end

function Lua_LuckyGiftBoxItem:sDrawBox()
	DataCenter.luckyGiftBoxData.showState = true;
	Lua_MsgUtil.callFunc("DRAW_LUCKYGIFTBOX_REWARD", self.data);
end

function Lua_LuckyGiftBoxItem:dispose()
	if self.boxIcon ~= nil then
		TweenUtil.getInstance():stop(self.boxIcon.mainContent);
	end
	if self.giftIcon ~= nil then
		TweenUtil.getInstance():stop(self.giftIcon.mainContent);
		self.giftIcon:dispose();
		self.giftIcon = nil;
	end
	self.data = nil;

	self:superCall("dispose");
end