Lua_SelectBestGiftBoxWindow = class("Lua_SelectBestGiftBoxWindow", Lua_Window);
function Lua_SelectBestGiftBoxWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_SelectBestGiftBoxWindow";
	self.skinName = "SelectBestGiftBoxWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
	self.showClose = true;
end

function Lua_SelectBestGiftBoxWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.isFirst = true;

	self.btnClose:setLocation(300, 455, 0);

	self.bestGiftIcon = Lua_ItemIcon.new(self.content);
	self.bestGiftIcon:setLocation(-252, 315);

	self.itemDesContainer = Lua_DragContainer.new(self.content, 440, 64, Lua_AxisDefine.Vertical);
	self.itemDesContainer:setLocation(75, 295, 0);
	self.itemDesContainer:setCellPivot(1);

	self.selectGiftList = Lua_DragList.new(self.content, 610, 540, Lua_AxisDefine.Vertical);
	self.selectGiftList:setListCell(Lua_SelectBestGiftBoxItem, 610, 160, 1);
	self.selectGiftList:setCellSpacing(0, 10);
	self.selectGiftList:setLocation(0, -80, 0);

	self.sureBtn:addClickFuntion(self, self.onSureBtnClick);

	self:addLuaEvent("UPDATE_SHOW_INFO", self, self.updateShowInfo);
	self:addLuaEvent("UPDATE_LUCKYGIFTBOX_BESTGIFT_INFO", self, self.updateBestGiftBoxInfo);
end

function Lua_SelectBestGiftBoxWindow:showWin(param)
	self:superCall("showWin", param);
	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sBestGiftBoxInfo(param);
end

function Lua_SelectBestGiftBoxWindow:updateBestGiftBoxInfo()
	self.titleTxt.text = LanUtil.formateStr("第{1}轮终极奖励", DataCenter.luckyGiftBoxData.round);

	self:updateShowInfo();

	self.selectGiftList:setArrayData(DataCenter.luckyGiftBoxData.bestGiftInfoDic);
end

function Lua_SelectBestGiftBoxWindow:updateShowInfo(data)
	local luckyGiftBoxData = DataCenter.luckyGiftBoxData;
	local tvo;
	local giftId;
	if data ~= nil then
		tvo = data.tvo;
		giftId = data.tvo.id;
	else
		giftId = luckyGiftBoxData.advance_gift_id;
		tvo = Lua_ToolVo.createToolVo(luckyGiftBoxData.advance_gift_id, luckyGiftBoxData.advance_gift_amount);
	end
	self.bestGiftIcon:setData(tvo);
	self.bestGiftNameTxt.text = tvo.name;

	self.curCountTxt.text = LanUtil.formateStr("拥有：{1}", DataCenter.packData:getItemCountById(giftId));

	if self.isFirst then
		self.isFirst = false;
		self.itemDesContainer:addSubContainer(Lua_ItemDesItem, tvo.des, true, 0);
	end
	self.itemDesContainer:setChildData(tvo.des);
	self.itemDesContainer:updateChildPos();
	self.itemDesContainer.canDrag = not self.itemDesContainer.isTheEnd;
end

function Lua_SelectBestGiftBoxWindow:onSureBtnClick(go)
	local selecdtingIdx = DataCenter.luckyGiftBoxData.selecdtingIdx;
	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sChangeBestGiftBox(self.showData, selecdtingIdx);
	self:hide();
end

function Lua_SelectBestGiftBoxWindow:dispose()
	if self.bestGiftIcon ~= nil then
		self.bestGiftIcon:dispose();
		self.bestGiftIcon = nil;
	end
	if self.itemDesContainer ~= nil then
		self.itemDesContainer:dispose();
		self.itemDesContainer = nil;
	end
	if self.selectGiftList ~= nil then
		self.selectGiftList:dispose();
		self.selectGiftList = nil;
	end
	self.isFirst = true;

	self:superCall("dispose");
end





--------------------------------------------------





Lua_SelectBestGiftBoxItem = class("Lua_SelectBestGiftBoxItem", Lua_ListCell);
function Lua_SelectBestGiftBoxItem:ctor(p)
	self:superCall("ctor", p, "SelectBestGiftBoxItem_skin");
end

function Lua_SelectBestGiftBoxItem:buildShowItem()
	self:superCall("buildShowItem");

	self.bestGiftList = Lua_DragList.new(self.content, 440, 112, Lua_AxisDefine.Horizontal);
	self.bestGiftList:setListCell(Lua_BestGiftBoxItem, 112, 112, 1);
	self.bestGiftList:setCellSpacing(10, 0);
	self.bestGiftList:setLocation(68, 0, 0);
	self:setSubList(self.bestGiftList);
end

function Lua_SelectBestGiftBoxItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.lockIcon:setEnable(data.round > DataCenter.luckyGiftBoxData.round);

	self.bestGiftList:setArrayData(data.info);
	if data.round == DataCenter.luckyGiftBoxData.round then
		self.roundsTxt.text = "<color=#BC38B5>当前</color>";

		local curSelectIdx = DataCenter.luckyGiftBoxData.curSelectIdx;
		self.bestGiftList:moveToIndex(curSelectIdx, true, false);
		self.bestGiftList:setSelected(curSelectIdx);
	else
		self.roundsTxt.text = LanUtil.formateStr("第{1}轮", data.round);

		self.bestGiftList:moveToIndex(1, true, false);
		self.bestGiftList:setSelected(nil);
	end
end

function Lua_SelectBestGiftBoxItem:dispose()
	if self.bestGiftList ~= nil then
		self.bestGiftList:dispose();
		self.bestGiftList = nil;
	end
	self.data = nil;

	self:superCall("dispose");
end





--------------------------------------------------





Lua_BestGiftBoxItem = class("Lua_BestGiftBoxItem", Lua_ListCell);
function Lua_BestGiftBoxItem:ctor(p)
	self:superCall("ctor", p, "BestGiftBoxItem_skin");
end

function Lua_BestGiftBoxItem:buildShowItem()
	self:superCall("buildShowItem");

	self.giftIcon = Lua_ItemIcon.new(self.content);
	self.giftIcon:setSiblingIndex(0);
end

function Lua_BestGiftBoxItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.giftIcon:setData(data.tvo);

	self.mask:setEnable(true);
	self.lvTxt:setEnable(true);
	if data.round ~= DataCenter.luckyGiftBoxData.round then
		self.lvTxt.text = "不可选";
	else
		if DataCenter.roleData.level >= data.limit_level then
			self.mask:setEnable(false);
			self.lvTxt:setEnable(false);
		else
			self.lvTxt.text = LanUtil.formateStr("{1}级", data.limit_level);
		end
	end
end

function Lua_BestGiftBoxItem:onPressClick()
	local round = DataCenter.luckyGiftBoxData.round;
	if self.data.round < round then
		OperateAlert.show("该轮已完成");
	elseif self.data.round > round then
		OperateAlert.show("暂时未到可选轮次");
	else
		if DataCenter.roleData.level >= self.data.limit_level then
			DataCenter.luckyGiftBoxData.selecdtingIdx = self.cellSeqIndex;
			Lua_MsgUtil.callFunc("UPDATE_SHOW_INFO", self.data);
			return true;
		else
			OperateAlert.show(LanUtil.formateStr("{1}级后开启", self.data.limit_level));
		end
	end
end

function Lua_BestGiftBoxItem:onSelectionChange(bSelect)
	self:superCall("onSelectionChange", bSelect);

	self:updateSelect(bSelect);
end

function Lua_BestGiftBoxItem:updateSelect(state)
	self.selectingIcon:setEnable(state);
end

function Lua_BestGiftBoxItem:dispose()
	if self.giftIcon ~= nil then
		self.giftIcon:dispose();
		self.giftIcon = nil;
	end
	self.data = nil;
	DataCenter.luckyGiftBoxData.SelecdtingGift = 1;

	self:superCall("dispose");
end





--------------------------------------------------





Lua_ItemDesItem = class("Lua_ItemDesItem", Lua_ListCell);
function Lua_ItemDesItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_ItemDesItem:buildShowItem()
	self:superCall("buildShowItem");

	self.des = UICreate.createLabel(self.content, "", 0, 0, 442, 330, 26);
	self.des.verticalOverflowValue = 1;
	self.des.alignmentValue = 0;
end

function Lua_ItemDesItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.des.text = data;
end

function Lua_ItemDesItem:getWidth()
	return self.des.width;
end

function Lua_ItemDesItem:getHeight()
	return self.des.height;
end

function Lua_ItemDesItem:dispose()
	if self.des ~= nil then
		self.des:dispose();
		self.des = nil;
	end
	self.data = nil;

	self:superCall("dispose");
end