-- 怪物挑战（新英雄后台活动）
Lua_MonsterTrialPanel = class("Lua_MonsterTrialPanel", Lua_DisplayObject);
function Lua_MonsterTrialPanel:ctor(p, skinName)
	self:superCall("ctor", p, skinName);
end

function Lua_MonsterTrialPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.bg:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 1280 + self.adaptHeight);

	self.chapterList = Lua_DragList.new(self.content, 660, 746 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.chapterList:setListCell(Lua_MonsterTrialItem, 660, 190, 1);
	self.chapterList:setCellSpacing(0, 10);
	self.chapterList:setLocation(0, -160, 0);

	self.rankList = Lua_DragList.new(self.content, 276, 123, Lua_AxisDefine.Vertical);
	self.rankList:setListCell(Lua_MonsterTrialDesItem, 276, 30, 1);
	self.rankList:setRectAnchor(1);
	self.rankList:setCellSpacing(0, 10);
	self.rankList:setLocation(-170, -190, 0);
	self.rankList.canDrag = false;

	self.readMoreRankTxt:addClickFuntion(self, self.onMoreRankClick);
	self.levelBg:addClickFuntion(self, self.onShowLvInfoClick);
	self.tipsBtn:addClickFuntion(self, self.onTipsBtnClick);

	self:addLuaEvent("MONSTERTRIAL_EVENT", self, self.monsterTrialEvent);
	self:addLuaEvent("UPDATE_MONSTERTRIAL_INFO", self, self.updateMonsterTrialInfo);
	self:addLuaEvent("CHECK_MONSTERTRAIL_ISEND", self, self.checkMonsterTrialIsEnd);

	self:addLuaEvent("UPDATE_RANK_INFO", self, self.monsterTrialRank);
	Lua_ProxyManager.getProxy("Lua_RankProxy"):sGetRankInfo(Lua_RankData.MONSTER_TYPE); -- 排行榜信息
end

function Lua_MonsterTrialPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);

	self.bg:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 1280 + adaptHeight);
	self.chapterList:setContentRect(660, 746 + adaptHeight);
end

function Lua_MonsterTrialPanel:setData(data)
	self.data = data;
	self:startTimer();
end

function Lua_MonsterTrialPanel:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_MonsterTrialPanel", 1, self, self.updateLeftTime);
	end
end

function Lua_MonsterTrialPanel:updateLeftTime()
	if self.data.residueTime <= 0 then
		self:endTimer();
	end
	self.leftTimeTxt.text = LanUtil.formateStr("剩余时间：<color=#45BC56>{1}</color>", Lua_TimeTransform.transSeconds16(self.data.residueTime, true, true, true));
end

function Lua_MonsterTrialPanel:endTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.updateLeftTime);
	end
end

function Lua_MonsterTrialPanel:onMoreRankClick(go)
	if DataCenter.backstageActData:checkActIsEnd(self.data) then
		return;
	end
	Lua_WindowUtil.openWin("Lua_MonsterTrialRankWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_MonsterTrialPanel:onShowLvInfoClick(go)
	if DataCenter.backstageActData:checkActIsEnd(self.data) then
		return;
	end
	Lua_WindowUtil.openWin("Lua_MonsterTrialPowerTipsWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_MonsterTrialPanel:onTipsBtnClick(go)
	local tipData = { des = self.data.help_des, posX = 175, posY = -120 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_MonsterTrialPanel:monsterTrialRank(msg)
	local vo;
	local rankList = {};
	for i = 1, 3 do -- 只显示前三名
		if msg.rank_list[i] ~= nil then
			rankList[i] = {rank = msg.rank_list[i].rank, player_show = msg.rank_list[i].player_show, value = msg.rank_list[i].value};
		else
			rankList[i] = {rank = i};
		end
	end
	self.rankList:setArrayData(rankList);
end

function Lua_MonsterTrialPanel:monsterTrialEvent(data)
	if data.eventType == 1 then
		Lua_ProxyManager.getProxy("Lua_NewHeroActivityProxy"):sMonsterTrialRewardInfo(self.data.actIdx);
	end
end

function Lua_MonsterTrialPanel:updateMonsterTrialInfo()
	local newHeroActData = DataCenter.newHeroActData;
	self.levelTxt.text = newHeroActData.buff_info.buff_lvl;
	self.limitTimesTxt.text = LanUtil.formateStr("今日剩余挑战次数：<color=#45BC56>{1}/{2}</color>", newHeroActData.free_times, newHeroActData.free_limit);

	local tab = {newHeroActData.buff_info.cur_exe, newHeroActData.buff_info.exe_limit};
	self.progressBar:setText(table.concat(tab, "/"));
	self.progressBar:setMaxValue(newHeroActData.buff_info.exe_limit);
	self.progressBar:setValue(newHeroActData.buff_info.cur_exe);

	table.sort(newHeroActData.stage_info, function(a, b) return a.id < b.id end);
	self.chapterList:setArrayData(newHeroActData.stage_info);
end

function Lua_MonsterTrialPanel:checkMonsterTrialIsEnd(data)
	if DataCenter.backstageActData:checkActIsEnd(self.data) then
		return;
	end

	local sceneId = DataCenter.heroLineupData:getFightLineupSceneId(Lua_FightDefine.TEMPLATE_ID_MONSTERTRIAL);
	DataCenter.preLoadData:preShowScene("Lua_FightLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, data, sceneId, 0);
end

function Lua_MonsterTrialPanel:onSceneShow(param)
	local list = {}
	list.template_id = Lua_FightDefine.TEMPLATE_ID_MONSTERTRIAL;
	list.stage_id = param; -- 关卡id
	-- list.monster_player_id = 10000002; -- 机器人ID mainline_game_level，显示 Lua_FightLineupWindow 的顶部对象
	Lua_WindowUtil.openWin("Lua_FightLineupWindow", Lua_WinParam.ACTION_OPEN, list);
end

function Lua_MonsterTrialPanel:dispose()
	if self.chapterList ~= nil then
		self.chapterList:dispose();
		self.chapterList = nil;
	end
	DataCenter.preLoadData:removeBySign("Lua_FightLineupWindow", self, self.onSceneShow);
	self.data = nil;
	self:endTimer();

	self:superCall("dispose");
end





--------------------------------------------------





Lua_MonsterTrialItem = class("Lua_MonsterTrialItem", Lua_ListCell);
function Lua_MonsterTrialItem:ctor(p)
	self:superCall("ctor", p, "MonsterTrialItem_skin");
end

function Lua_MonsterTrialItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardList = Lua_DragList.new(self.content, 300, 112, Lua_AxisDefine.Horizontal);
	self.rewardList:setListCell(Lua_ItemIconCell, 112, 112, 1);
	self.rewardList:setLocation(-185, -26, 0);
	self.rewardList:setRectPivot(3);
	self:setSubList(self.rewardList);

	self.challengeBtn:addClickFuntion(self, self.onChallengeClick);
end

function Lua_MonsterTrialItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.desTxt.text = data.chaper_title;
	self.chapterTxt.text = data.title;

	if data.special == 1 then
		self.integralTxt.text = LanUtil.formateStr("当前积分：<color=#45BC56>{1}</color>", data.score);
	else
		self.integralTxt.text = LanUtil.formateStr("当前积分：<color=#45BC56>{1}/{2}</color>", data.score, data.score_limit);
	end

	local tvo;
	local rewardArr = Array();
	for i = 1, #data.reward do
		tvo = Lua_ToolVo.createToolVo(data.reward[i].key, data.reward[i].value);
		rewardArr:add(tvo);
	end
	self.rewardList:setArrayData(rewardArr);
	self.rewardList.canDrag = rewardArr:getSize() > 2;
	if rewardArr:getSize() > 2 then
		self.rewardList:setContentRect(300, 112);
	else
		self.rewardList:setContentRect(112 * rewardArr:getSize(), 112);
	end

	if data.state == 1 then
		self.challengeBtn.label = "挑战";
		self.challengeBtn:setMouseEnable(true);
		self.challengeBtn:addClickFuntion(self, self.onChallengeClick);
	else
		self.challengeBtn.label = "未解锁";
		self.challengeBtn:setMouseEnable(false);
	end

	self.desTxt:setEnable(data.state == 0);
	self.seniorRewardMask:setEnable(data.state == 0);
	self.lockObj:SetActive(data.state == 0);
end

function Lua_MonsterTrialItem:onChallengeClick(go)
	if self.data.state == 1 then
		Lua_MsgUtil.callFunc("CHECK_MONSTERTRAIL_ISEND", self.data.id);
	end
end
function Lua_MonsterTrialItem:dispose()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	self.data = nil;

	self:superCall("dispose");
end





--------------------------------------------------





Lua_MonsterTrialDesItem = class("Lua_MonsterTrialDesItem", Lua_ListCell);
function Lua_MonsterTrialDesItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_MonsterTrialDesItem:buildShowItem()
	self:superCall("buildShowItem");

	self.desTxt = UICreate.createLabel(self.content, "", -50, 0, 176, 180, 30);
	self.desTxt.fontName = Lua_MyUISettings.huakangFontName;
	self.desTxt.colorStr = Lua_ColorDefine.transColorStr("669FFF");
	self.desTxt.verticalOverflowValue = 1;
	self.desTxt.alignmentValue = 3;

	self.integralTxt = UICreate.createLabel(self.content, "", 100, 0, 88, 180, 30);
	self.integralTxt.fontName = Lua_MyUISettings.huakangFontName;
	self.integralTxt.colorStr = Lua_ColorDefine.transColorStr("669FFF");
	self.integralTxt.verticalOverflowValue = 1;
	self.integralTxt.alignmentValue = 7;
end

function Lua_MonsterTrialDesItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	if data.player_show ~= nil then
		self.desTxt.text = LanUtil.formateStr("{1}  {2}", data.rank, data.player_show.name);
		self.integralTxt.text = data.value;
	else
		self.desTxt.text = LanUtil.formateStr("{1}  {2}", data.rank, "虚位以待");
		self.integralTxt.text = "";
	end

	self.integralTxt:setEnable(data.player_show ~= nil);
end

function Lua_MonsterTrialDesItem:dispose()
	if self.desTxt ~= nil then
		self.desTxt:dispose();
		self.desTxt = nil;
	end
	if self.integralTxt ~= nil then
		self.integralTxt:dispose();
		self.integralTxt = nil;
	end
	self.data = nil;

	self:superCall("dispose");
end