Lua_MonsterTrialRankPanel = class("Lua_MonsterTrialRankPanel", Lua_DisplayObject);
function Lua_MonsterTrialRankPanel:ctor(p)
	self:superCall("ctor", p, "MonsterTrialRankPanel_skin");
end

function Lua_MonsterTrialRankPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.allRankBg:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 565 + self.adaptHeight);

	self.modelArr = Array();
	self.modelItemArr = Array();

	self.itemList = Lua_DragList.new(self.content, 690, 570 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList:setListCell(Lua_MonsterTrialRankItem, 690, 123, 1);
	self.itemList:setLocation(0, -114, 0);
	self.itemList:setCellSpacing(0, 10);

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setLocation(-160, 195, 0);
	self.avatarItem:setAvatarClick(self, self.avatarCallBack);
	self.avatarItem:setRectAnchor(7);

	self.rankNum = Lua_NumberImage.new(self.content);
	self.rankNum:setLocation(-282, 192, 0);
	self.rankNum:setRectAnchor(7);
	self.rankNum.pivot = 0;
	self.rankNum.numOffsetX = -2;
	self.rankNum.numAtlas = "number";
	self.rankNum.lastStr = nil;
	self.rankNum.preStr = "ui_djc2_title_0";
	self.rankNum.num = 0;
	self.rankNum:setEnable(false);

	self:addLuaEvent("UPDATE_RANK_INFO", self, self.updateShowInfo);
	Lua_ProxyManager.getProxy("Lua_RankProxy"):sGetRankInfo(Lua_RankData.MONSTER_TYPE); -- 排行榜信息
end

function Lua_MonsterTrialRankPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);

	self.allRankBg:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 570 + adaptHeight);

	self.itemList:setContentRect(690, 564 + adaptHeight);
end

function Lua_MonsterTrialRankPanel:updateShowInfo(msg)
	if msg == nil then
		return;
	end

	local obj;
	local rankArr = Array();
	for i = 1, #msg.rank_list do
		obj = msg.rank_list[i];
		if obj.rank > 3 then
			rankArr:add(obj);
		else
			self.modelArr:add(obj);
		end
	end
	rankArr:sort("rank", false); -- 第四名及之后排行
	self.modelArr:sort("rank", false); -- 前三排行
	self.itemList:setArrayData(rankArr);

	self:updateModelInfo();
	self:updateSelfInfo(msg.self_rank);
end

-- 更新三个模型信息
function Lua_MonsterTrialRankPanel:updateModelInfo()
	local posTab = {{0, -355}, {-245, -388}, {245, -388}};
	local item;
	for i = 1, 3 do
		item = self.modelItemArr[i];
		if item == nil then
			item = Lua_MonsterTrialRankModelItem.new(self.content);
			self.modelItemArr:add(item);
		end
		item:setRectAnchor(4);
		item:setLocation(posTab[i][1], posTab[i][2], 0);
		item:setRectAnchor(1);
		item:setData(i, self.modelArr[i]);
	end
end

function Lua_MonsterTrialRankPanel:updateSelfInfo(data)
	self.data = data;

	self.avatarItem:setRoleAvatar(DataCenter.roleData.head_id); -- data.head_id);
	self.myNameTxt.text = data.player_show.name;
	self.myintegralTxt.text = data.value;
	if data.rank <= 0 then
		self.myRankTxt.text = "未上榜"; -- 没有美术字，先用文字代替
	else
		self.rankNum.num = data.rank;
	end
	self.rankNum:setEnable(data.rank > 0);
	self.myRankTxt:setEnable(data.rank <= 0);

	if data ~= nil and data.value == 0 then -- 未战斗过，不能点击
		self.fightIcon:setGray(true);
		self.fightIcon.mouseEnable = false;
	else
		self.fightIcon:setGray(false);
		self.fightIcon.mouseEnable = true;
		self.fightIcon:addClickFuntion(self, self.onMaxFightInfoClick);
	end
end

function Lua_MonsterTrialRankPanel:avatarCallBack()
	OperateAlert.show("这是你自己");
end

function Lua_MonsterTrialRankPanel:onMaxFightInfoClick(go)
	if self.data == nil then
		return;
	end
	-- print("自己的历史最高积分的战斗数据");
	Lua_WindowUtil.openWin("Lua_FightOverallHurtWindow", Lua_WinParam.ACTION_OPEN, self.data.hurt_collect);
end

function Lua_MonsterTrialRankPanel:dispose()
	if self.modelArr ~= nil then
		self.modelArr:dispose();
		self.modelArr:clear();
		self.modelArr = nil;
	end
	if self.modelItemArr ~= nil then
		self.modelItemArr:dispose();
		self.modelItemArr:clear();
		self.modelItemArr = nil;
	end
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.rankNum ~= nil then
		self.rankNum:dispose();
		self.rankNum = nil;
	end
	self.data = nil;

	self:superCall("dispose");
end





--------------------------------------------------





Lua_MonsterTrialRankModelItem = class("Lua_MonsterTrialRankModelItem", Lua_ListCell);
function Lua_MonsterTrialRankModelItem:ctor(p)
	self:superCall("ctor", p, "MonsterTrialRankModelItem_skin");
end

function Lua_MonsterTrialRankModelItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_MonsterTrialRankModelItem:setData(rank, data)
	self.data = data;

	self.designation:setAltas("arena_atlas_1", "ui_grxx_ch_0"..rank);
	self.rankIcon:setAltas("arena_atlas_1", "ui_djc_label_0"..rank);

	if data == nil then
		if self.modelEffImg ~= nil then
			self.modelEffImg:setEnable(false);
		end
		self.nameTxt.text = "虚位以待";
		self.integralTxt.text = "";
	else
		if self.modelEffImg == nil then
			self.modelEffImg = UICreate.createModelEffImg(self.content, "/model/102000505_low", "102000505_low", 0, 155, 0, 0);
			self.modelEffImg:setCamField(1, 1, 100, true);
			self.modelEffImg:setCamPos(0, 1, -10);
			self.modelEffImg:setModelEffDir(90);
			self.modelEffImg.canRot = false;
			self.modelEffImg:addClickFuntion(self, self.modelEffImgCallBack);
		end
		self.modelEffImg:setEnable(true);
		self.modelEffImg:setScale(0.25, 0.25, 0.25);

		self.nameTxt.text = data.player_show.name;
		self.integralTxt.text = data.value;
	end

	if data ~= nil and data.value == 0 then 
		self.fightIcon:setGray(true);
		self.fightIcon.mouseEnable = false;
	else
		self.fightIcon:setGray(false);
		self.fightIcon.mouseEnable = true;
		self.fightIcon:addClickFuntion(self, self.onMaxFightInfoClick);
	end

	self.roleIcon:setEnable(data == nil);
end

function Lua_MonsterTrialRankModelItem:modelEffImgCallBack()
	if tonumber(self.data.player_show.id) == DataCenter.roleData.roleId then
		OperateAlert.show("这是你自己");
		return;
	end
	Lua_WindowUtil.openWin("Lua_PlayerInfoWindow", Lua_WinParam.ACTION_OPEN, tonumber(self.data.player_show.id));
end

function Lua_MonsterTrialRankModelItem:onMaxFightInfoClick(go)
	if self.data == nil then
		return;
	end
	-- print("模型的历史最高积分的战斗数据");
	Lua_WindowUtil.openWin("Lua_FightOverallHurtWindow", Lua_WinParam.ACTION_OPEN, self.data.hurt_collect);
end

function Lua_MonsterTrialRankModelItem:dispose()
	if self.modelEffImg ~= nil then
		self.modelEffImg:dispose();
		self.modelEffImg = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end





--------------------------------------------------





Lua_MonsterTrialRankItem = class("Lua_MonsterTrialRankItem", Lua_ListCell);
function Lua_MonsterTrialRankItem:ctor(p)
	self:superCall("ctor", p, "MonsterTrialRankItem_skin");
end

function Lua_MonsterTrialRankItem:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setLocation(-166, 0, 0);
	self.avatarItem:setAvatarClick(self, self.avatarCallBack);

	self.rankNum = Lua_NumberImage.new(self.content);
	self.rankNum:setLocation(-282, 0, 0);
	self.rankNum.pivot = 0;
	self.rankNum.numOffsetX = -4;
	self.rankNum.numAtlas = "number";
	self.rankNum.lastStr = nil;
	self.rankNum.preStr = "ui_djc_title_0";
end

function Lua_MonsterTrialRankItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.rankNum.num = data.rank;
	self.avatarItem:setRoleAvatar(data.head_id);
	self.nameTxt.text = data.player_show.name;
	self.integralTxt.text = LanUtil.formateStr("积分：{1}", data.value);

	if data ~= nil and data.value == 0 then 
		self.fightIcon:setGray(true);
		self.fightIcon.mouseEnable = false;
	else
		self.fightIcon:setGray(false);
		self.fightIcon.mouseEnable = true;
		self.fightIcon:addClickFuntion(self, self.onMaxFightInfoClick);
	end
end

function Lua_MonsterTrialRankItem:avatarCallBack()
	if tonumber(self.data.player_show.id) == DataCenter.roleData.roleId then
		OperateAlert.show("这是你自己");
		return;
	end
	Lua_WindowUtil.openWin("Lua_PlayerInfoWindow", Lua_WinParam.ACTION_OPEN, tonumber(self.data.player_show.id));
end

function Lua_MonsterTrialRankItem:onMaxFightInfoClick(go)
	if self.data == nil then
		return;
	end
	-- print("单个玩家历史最高积分的战斗数据");
	-- Lua_WindowUtil.openWin("Lua_FightOverallHurtWindow", Lua_WinParam.ACTION_OPEN, self.data.hurt_collect);
end

function Lua_MonsterTrialRankItem:dispose()
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.rankNum ~= nil then
		self.rankNum:dispose();
		self.rankNum = nil;
	end
	self.data = nil;

	self:superCall("dispose");
end